package betterquesting.misc;

import betterquesting.core.BetterQuesting;
import com.google.common.base.Splitter;
import com.google.common.collect.Lists;
import com.google.common.collect.Sets;
import java.awt.image.BufferedImage;
import java.io.Closeable;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import net.minecraft.client.resources.IResourcePack;
import net.minecraft.client.resources.ResourcePackFileNotFoundException;
import net.minecraft.client.resources.data.IMetadataSection;
import net.minecraft.client.resources.data.IMetadataSerializer;
import net.minecraft.util.ResourceLocation;
import org.apache.logging.log4j.Level;

/* loaded from: betterquesting_misc.jar:betterquesting/misc/QuestResourcesFile.class */
public class QuestResourcesFile implements IResourcePack, Closeable {
    private static final File rootFolder = new File("config/betterquesting/resources/");
    public static final Splitter entryNameSplitter = Splitter.on('/').omitEmptyStrings().limit(3);
    ArrayList<ZipFile> zipList = null;

    public InputStream func_110590_a(ResourceLocation loc) throws IOException {
        String locName = locationToName(loc);
        for (ZipFile zipfile : getZipFiles()) {
            ZipEntry zipentry = zipfile.getEntry(locName);
            if (zipentry != null) {
                return zipfile.getInputStream(zipentry);
            }
        }
        throw new ResourcePackFileNotFoundException(rootFolder, locName);
    }

    public boolean func_110589_b(ResourceLocation loc) {
        String locName = locationToName(loc);
        try {
            for (ZipFile zipfile : getZipFiles()) {
                ZipEntry zipentry = zipfile.getEntry(locName);
                if (zipentry != null) {
                    return true;
                }
            }
            return false;
        } catch (Exception e) {
            return false;
        }
    }

    public Set<String> func_110587_b() {
        HashSet<String> hashset = Sets.newHashSet();
        try {
            for (ZipFile f : getZipFiles()) {
                hashset.addAll(GetZipDomains(f));
            }
        } catch (Exception e) {
        }
        return hashset;
    }

    public Set<String> GetZipDomains(ZipFile zipfile) {
        Enumeration<? extends ZipEntry> enumeration = zipfile.entries();
        HashSet<String> hashset = Sets.newHashSet();
        while (enumeration.hasMoreElements()) {
            ZipEntry zipentry = enumeration.nextElement();
            String s = zipentry.getName();
            if (s.startsWith("assets/")) {
                ArrayList<String> arraylist = Lists.newArrayList(entryNameSplitter.split(s));
                if (arraylist.size() > 1) {
                    String s1 = arraylist.get(1);
                    if (!s1.equals(s1.toLowerCase())) {
                        logNameNotLowercase(s1, zipfile.getName());
                    } else {
                        hashset.add(s1);
                    }
                }
            }
        }
        return hashset;
    }

    public IMetadataSection func_135058_a(IMetadataSerializer meta, String s) throws IOException {
        return null;
    }

    public BufferedImage func_110586_a() throws IOException {
        return null;
    }

    public String func_130077_b() {
        return "BetterQuesting_files";
    }

    private List<ZipFile> getZipFiles() throws IOException {
        if (this.zipList != null) {
            return this.zipList;
        }
        if (!rootFolder.exists()) {
            rootFolder.mkdirs();
        }
        File[] files = rootFolder.listFiles();
        this.zipList = new ArrayList<>();
        for (File f : files) {
            if (f.exists() && f.isFile()) {
                try {
                    this.zipList.add(new ZipFile(f));
                } catch (Exception e) {
                }
            }
        }
        return this.zipList;
    }

    private static String locationToName(ResourceLocation loc) {
        return String.format("%s/%s/%s", "assets", loc.func_110624_b(), loc.func_110623_a());
    }

    protected void logNameNotLowercase(String name, String file) {
        BetterQuesting.logger.log(Level.WARN, "ResourcePack: ignored non-lowercase namespace: {} in {}", new Object[]{name, file});
    }

    public void finalize() throws Throwable {
        close();
        super.finalize();
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        if (this.zipList != null) {
            Iterator<ZipFile> it = this.zipList.iterator();
            while (it.hasNext()) {
                ZipFile zip = it.next();
                if (zip != null) {
                    zip.close();
                }
            }
            this.zipList = null;
        }
    }
}
